<?php
// File: $Id: bbcode.lib.php,v 1.4 2004/03/21 16:22:33 markwest Exp $
/**
 * pn_bbdecode/pn_bbencode functions:
 * Rewritten - Nathan Codding - Aug 24, 2000
 * Using Perl-Compatible regexps now. Won't kill special chars
 * outside of a [code]...[/code] block now, and all BBCode tags
 * are implemented.
 * Note: the "i" matching switch is used, so BBCode tags are
 * case-insensitive.
 */
function pn_bbdecode($message) {

		// Undo [code]
		$message = preg_replace("#<!-- BBCode Start --><table border=\"0\" align=\"center\" width=\"85%\"><tr><td>Code:hr /</td></tr><tr><td><pre>(.*?)</pre></td></tr><tr><td>hr /</td></tr></table><!-- BBCode End -->#s", "[code]\\1[/code]", $message);

		// Undo [quote]
		$message = preg_replace("#<!-- BBCode Quote Start --><table border=\"0\" align=\"center\" width=\"85%\"><tr><td>Quote:hr /</td></tr><tr><td><blockquote>(.*?)</blockquote></td></tr><tr><td>hr /</td></tr></table><!-- BBCode Quote End -->#s", "[quote]\\1[/quote]", $message);

		// Undo [b] and [i]
		$message = preg_replace("#<!-- BBCode Start --><strong>(.*?)</strong><!-- BBCode End -->#s", "[b]\\1[/b]", $message);
		$message = preg_replace("#<!-- BBCode Start --><em>(.*?)</em><!-- BBCode End -->#s", "[i]\\1[/i]", $message);

		// Undo [url] (both forms)
		$message = preg_replace("#<!-- BBCode Start --><a href=\"http://(.*?)\" target=\"_blank\">(.*?)<</a><!-- BBCode End -->#s", "[url=\\1]\\2[/url]", $message);

		// Undo [email]
		$message = preg_replace("#<!-- BBCode Start --><a href=\"mailto:(.*?)\">(.*?)<</a><!-- BBCode End -->#s", "[email]\\1[/email]", $message);

		// Undo [img]
		$message = preg_replace("#<!-- BBCode Start --><img src=\"http://(.*?)\"><!-- BBCode End -->#s", "[img]http://\\1[/img]", $message);
		//$message = preg_replace("#<!-- BBCode Start --><img src=\"(.*?)\"><!-- BBCode End -->#s", "[img]\\1[/img]", $message);

		// Undo lists (unordered/ordered)

		// unordered list code..
		$matchCount = preg_match_all("#<!-- BBCode ulist Start --><UL>(.*?)</UL><!-- BBCode ulist End -->#s", $message, $matches);

		for ($i = 0; $i < $matchCount; $i++)
		{
			$currMatchTextBefore = preg_quote($matches[1][$i]);
			$currMatchTextAfter = preg_replace("#<li>#s", "[*]", $matches[1][$i]);

			$message = preg_replace("#<!-- BBCode ulist Start --><UL>$currMatchTextBefore</UL><!-- BBCode ulist End -->#s", "[list]" . $currMatchTextAfter . "[/list]", $message);
		}

		// ordered list code..
		$matchCount = preg_match_all("#<!-- BBCode olist Start --><OL type=([A1])>(.*?)</OL><!-- BBCode olist End -->#si", $message, $matches);

		for ($i = 0; $i < $matchCount; $i++)
		{
			$currMatchTextBefore = preg_quote($matches[2][$i]);
			$currMatchTextAfter = preg_replace("#<li>#s", "[*]", $matches[2][$i]);

			$message = preg_replace("#<!-- BBCode olist Start --><OL type=([A1])>$currMatchTextBefore</OL><!-- BBCode olist End -->#si", "[list=\\1]" . $currMatchTextAfter . "[/list]", $message);
		}

		return($message);
}

function pn_bbencode($message) {

	// [CODE] and [/CODE] for posting code (HTML, PHP, C etc etc) in your posts.
	$matchCount = preg_match_all("#\[code\](.*?)\[/code\]#si", $message, $matches);

	for ($i = 0; $i < $matchCount; $i++)
	{
		$currMatchTextBefore = preg_quote($matches[1][$i]);
		$currMatchTextAfter = htmlspecialchars($matches[1][$i]);
		$message = preg_replace("#\[code\]$currMatchTextBefore\[/code\]#si", "<!-- BBCode Start --><table border=\"0\" align=\"center\" width=\"85%\"><tr><td>Code:hr /</td></tr><tr><td><pre>$currMatchTextAfter</pre></td></tr><tr><td>hr /</td></tr></table><!-- BBCode End -->", $message);
	}

	// [QUOTE] and [/QUOTE] for posting replies with quote, or just for quoting stuff.
	$message = preg_replace("#\[quote\](.*?)\[/quote]#si", "<!-- BBCode Quote Start --><table border=\"0\" align=\"center\" width=\"85%\"><tr><td>Quote:hr /</td></tr><tr><td><blockquote>\\1</blockquote></td></tr><tr><td>hr /</td></tr></table><!-- BBCode Quote End -->", $message);

	// [b] and [/b] for bolding text.
	$message = preg_replace("#\[b\](.*?)\[/b\]#si", "<!-- BBCode Start --><strong>\\1</strong><!-- BBCode End -->", $message);

	// [i] and [/i] for italicizing text.
	$message = preg_replace("#\[i\](.*?)\[/i\]#si", "<!-- BBCode Start --><em>\\1</em><!-- BBCode End -->", $message);

	// [url]www.phpbb.com[/url] code..
	$message = preg_replace("#\[url\](http://)?(.*?)\[/url\]#si", "<!-- BBCode Start --><a href=\"http://\\2\" target=\"_blank\">\\2<</a><!-- BBCode End -->", $message);

	// [url=www.phpbb.com]phpBB[/url] code..
	$message = preg_replace("#\[url=(http://)?(.*?)\](.*?)\[/url\]#si", "<!-- BBCode Start --><a href=\"http://\\2\" target=\"_blank\">\\3<</a><!-- BBCode End -->", $message);

	// [email]user@domain.tld[/email] code..
	$message = preg_replace("#\[email\](.*?)\[/email\]#si", "<!-- BBCode Start --><a href=\"mailto:\\1\">\\1<</a><!-- BBCode End -->", $message);

	// [img]image_url_here[/img] code..
	$message = preg_replace("#\[img\](http://)?(.*?)\[/img\]#si", "<!-- BBCode Start --><img src=\"http://\\2\"><!-- BBCode End -->", $message);
	// $message = preg_replace("#\[img\](.*?)\[/img\]#si", "<!-- BBCode Start --><img src=\"\\1\"><!-- BBCode End -->", $message);


	// unordered list code..
	$matchCount = preg_match_all("#\[list\](.*?)\[/list\]#si", $message, $matches);

	for ($i = 0; $i < $matchCount; $i++)
	{
		$currMatchTextBefore = preg_quote($matches[1][$i]);
		$currMatchTextAfter = preg_replace("#\[\*\]#si", "<li>", $matches[1][$i]);

		$message = preg_replace("#\[list\]$currMatchTextBefore\[/list\]#si", "<!-- BBCode ulist Start --><ul>$currMatchTextAfter</ul><!-- BBCode ulist End -->", $message);
	}

	// ordered list code..
	$matchCount = preg_match_all("#\[list=([a1])\](.*?)\[/list\]#si", $message, $matches);

	for ($i = 0; $i < $matchCount; $i++)
	{
		$currMatchTextBefore = preg_quote($matches[2][$i]);
		$currMatchTextAfter = preg_replace("#\[\*\]#si", "<li>", $matches[2][$i]);

		$message = preg_replace("#\[list=([a1])\]$currMatchTextBefore\[/list\]#si", "<!-- BBCode olist Start --><ol type=\\1>$currMatchTextAfter</ol><!-- BBCode olist End -->", $message);
	}

	return($message);
}

?>